AppLockTime class

Inheritance

Constructors

AppLockTime({Key? key, required Widget child, required String lockDate, required String password, required String titleApp, bool isEnabled = true, String titleText = "App Locked", String passwordHintText = "Enter Password", String confirmButtonText = "Confirm", String incorrectPasswordText = "❌ كلمة المرور غير صحيحة!", Color backgroundColor = Colors.white, Color textColor = Colors.black, Color buttonColor = Colors.blue, Color fieldBorderColor = Colors.grey, Color errorTextColor = Colors.red, double buttonWidth = 150, double buttonHeight = 50})
const

Properties

backgroundColor Color
final
buttonColor Color
final
buttonHeight double
final
buttonWidth double
final
child Widget
final
confirmButtonText String
final
errorTextColor Color
final
fieldBorderColor Color
final
hashCode int
The hash code for this object.
no setterinherited
incorrectPasswordText String
final
isEnabled bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lockDate String
final
password String
final
passwordHintText String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color
final
titleApp String
final
titleText String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AppLockTimeState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited